# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from px import px_pb2 as px_dot_px__pb2


class BrowserStub(object):
    """Missing associated documentation comment in .proto file"""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Do = channel.unary_unary(
                '/px.Browser/Do',
                request_serializer=px_dot_px__pb2.DoRequest.SerializeToString,
                response_deserializer=px_dot_px__pb2.DoResponse.FromString,
                )


class BrowserServicer(object):
    """Missing associated documentation comment in .proto file"""

    def Do(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BrowserServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Do': grpc.unary_unary_rpc_method_handler(
                    servicer.Do,
                    request_deserializer=px_dot_px__pb2.DoRequest.FromString,
                    response_serializer=px_dot_px__pb2.DoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'px.Browser', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Browser(object):
    """Missing associated documentation comment in .proto file"""

    @staticmethod
    def Do(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/px.Browser/Do',
            px_dot_px__pb2.DoRequest.SerializeToString,
            px_dot_px__pb2.DoResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)
